@@ -1,12 +1,4 @@
-pdfc <- function (file = "Rplot.pdf", ...) {
-  current.device <- dev.cur()
-  dev.off(dev.copy(device = pdf, file = file, ...))
-  dev.set(current.device)
-  print(paste(file, "generated."))
-  }
-
-lpr <- function (object, file = "Rplotlpr.ps", ...) 
-{
+lpr <- function (object, file = "Rplotlpr.ps", ...) {
     if (missing(object)) {
         current.device <- dev.cur()
         dev.off(dev.copy(device = postscript, file = file, ...))
@@ -15,7 +7,7 @@ lpr <- function (object, file = "Rplotlpr.ps", ...)
         print(paste(file, "printed."))
     }
     else {
-        if (missing(file)) 
+        if (missing(file))
             file <- "Robjlpr.txt"
         sink(file)
         object <- as.character(substitute(object))
