@@ -1,11 +1,9 @@
-ls.functions <- function()
-{
+ls.functions <- function() {
    x <- eval.parent(quote(ls()))
    x[sapply(x, function(x) typeof(get(x)) == "closure")]
 }
 
-ls.notfunctions <- function()
-{
+ls.notfunctions <- function() {
    x <- eval.parent(quote(ls()))
    x[sapply(x, function(x) typeof(get(x)) != "closure")]
 }
