@@ -1,8 +1,8 @@
-pad <- function( str, space, loc = c("right", "left", "center", "none"),
+pad <- function(str, space, just = c("right", "left", "center", "none"),
                   with=" ") {
   res  <- str
-  loc <- match.arg(loc)
-  if ( loc == "none" )
+  just <- match.arg(just)
+  if (just == "none")
     res  <- NA else {
     if (with == "") with <- " "
     for ( kk in seq_along(str) ) {
@@ -10,23 +10,23 @@ pad <- function( str, space, loc = c("right", "left", "center", "none"),
       jj <- ceiling(free / nchar(with))
       fill <- if ( free > 0 )
         substring(paste(rep.int(with, jj), collapse = ""),1,free) else ""
-      res[kk] <- if (free <= 0) { str[kk]
-      } else switch(loc,
-        "left"  = paste0(fill,str[kk]),
-        "right" = paste0(str[kk],fill),
-        "center"= {hf <- (free+1) %/% 2; paste0(substring(fill,1,hf),str[kk],substring(fill, 1+hf,free))}          
-                    )
+      res[kk] <- if (free <= 0) {
+           str[kk]
+        } else {
+          switch(just,
+            "left"  = paste0(fill,str[kk]),
+            "right" = paste0(str[kk],fill),
+            "center"= {
+                hf <- (free + 1) %/% 2
+                paste0(substring(fill, 1, hf), str[kk],
+                       substring(fill, 1+hf,free))
+              }              
+            )
+          }
       } # kk
     } # else NA
   return(res)
-} # pad
-
-justify <- function( str, space, loc = c("right", "left", "center", "none"), with=" ") {
-# exchange 'right' and 'left'
-  loc  <- match.arg(loc)
-  loc1 <- exch( loc, "right", "left" )
-  return( pad( str, space, loc1, with ) )
-} # justify
+}
 
 insstr <- function( str, ins, point=nchar(str) ) {
   res <- str
@@ -38,3 +38,9 @@ insstr <- function( str, ins, point=nchar(str) ) {
   } # ii
   return( res )     
 }
+
+justify <- function(str, space, just = c("right", "left", "center", "none"), with=" ") {
+  loc  <- match.arg(just)
+  loc1 <- exch( loc, "right", "left" )
+  return( pad( str, space, loc1, with ) )
+}
